@@ -128,7 +128,7 @@ class AmiContextQuery():
 
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.ArtifactManifest", jsii_struct_bases=[], name_mapping={'type': 'type', 'dependencies': 'dependencies', 'environment': 'environment', 'metadata': 'metadata', 'properties': 'properties'})
 class ArtifactManifest():
-    def __init__(self, *, type: "ArtifactType", dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List["MetadataEntry"]]]=None, properties: typing.Optional[typing.Mapping[str, typing.Any]]=None) -> None:
+    def __init__(self, *, type: "ArtifactType", dependencies: typing.Optional[typing.List[str]]=None, environment: typing.Optional[str]=None, metadata: typing.Optional[typing.Mapping[str, typing.List["MetadataEntry"]]]=None, properties: typing.Optional[typing.Union[typing.Optional["AwsCloudFormationStackProperties"], typing.Optional["AssetManifestProperties"], typing.Optional["TreeArtifactProperties"]]]=None) -> None:
         """A manifest for a single artifact within the cloud assembly.
 
         :param type: The type of artifact.
@@ -178,7 +178,7 @@ class ArtifactManifest():
         return self._values.get('metadata')
 
     @builtins.property
-    def properties(self) -> typing.Optional[typing.Mapping[str, typing.Any]]:
+    def properties(self) -> typing.Optional[typing.Union[typing.Optional["AwsCloudFormationStackProperties"], typing.Optional["AssetManifestProperties"], typing.Optional["TreeArtifactProperties"]]]:
         """The set of properties for this artifact (depends on type).
 
         default
@@ -221,6 +221,8 @@ class ArtifactType(enum.Enum):
     """The artifact is an AWS CloudFormation stack."""
     CDK_TREE = "CDK_TREE"
     """The artifact contains the CDK application's construct tree."""
+    ASSET_MANIFEST = "ASSET_MANIFEST"
+    """Manifest for all assets in the Cloud Assembly."""
 
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.AssemblyManifest", jsii_struct_bases=[], name_mapping={'version': 'version', 'artifacts': 'artifacts', 'missing': 'missing', 'runtime': 'runtime'})
 class AssemblyManifest():
@@ -285,6 +287,43 @@ class AssemblyManifest():
         return 'AssemblyManifest(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.AssetManifestProperties", jsii_struct_bases=[], name_mapping={'file': 'file', 'requires_bootstrap_stack_version': 'requiresBootstrapStackVersion'})
+class AssetManifestProperties():
+    def __init__(self, *, file: str, requires_bootstrap_stack_version: typing.Optional[jsii.Number]=None) -> None:
+        """Artifact properties for the Asset Manifest.
+
+        :param file: Filename of the asset manifest.
+        :param requires_bootstrap_stack_version: Version of bootstrap stack required to deploy this stack. Default: - Version 1 (basic modern bootstrap stack)
+        """
+        self._values = {
+            'file': file,
+        }
+        if requires_bootstrap_stack_version is not None: self._values["requires_bootstrap_stack_version"] = requires_bootstrap_stack_version
+
+    @builtins.property
+    def file(self) -> str:
+        """Filename of the asset manifest."""
+        return self._values.get('file')
+
+    @builtins.property
+    def requires_bootstrap_stack_version(self) -> typing.Optional[jsii.Number]:
+        """Version of bootstrap stack required to deploy this stack.
+
+        default
+        :default: - Version 1 (basic modern bootstrap stack)
+        """
+        return self._values.get('requires_bootstrap_stack_version')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'AssetManifestProperties(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.AvailabilityZonesContextQuery", jsii_struct_bases=[], name_mapping={'account': 'account', 'region': 'region'})
 class AvailabilityZonesContextQuery():
     def __init__(self, *, account: str, region: str) -> None:
@@ -318,6 +357,109 @@ class AvailabilityZonesContextQuery():
         return 'AvailabilityZonesContextQuery(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.AwsCloudFormationStackProperties", jsii_struct_bases=[], name_mapping={'template_file': 'templateFile', 'assume_role_arn': 'assumeRoleArn', 'cloud_formation_execution_role_arn': 'cloudFormationExecutionRoleArn', 'parameters': 'parameters', 'requires_bootstrap_stack_version': 'requiresBootstrapStackVersion', 'stack_name': 'stackName', 'stack_template_asset_object_url': 'stackTemplateAssetObjectUrl', 'termination_protection': 'terminationProtection'})
+class AwsCloudFormationStackProperties():
+    def __init__(self, *, template_file: str, assume_role_arn: typing.Optional[str]=None, cloud_formation_execution_role_arn: typing.Optional[str]=None, parameters: typing.Optional[typing.Mapping[str, str]]=None, requires_bootstrap_stack_version: typing.Optional[jsii.Number]=None, stack_name: typing.Optional[str]=None, stack_template_asset_object_url: typing.Optional[str]=None, termination_protection: typing.Optional[bool]=None) -> None:
+        """Artifact properties for CloudFormation stacks.
+
+        :param template_file: A file relative to the assembly root which contains the CloudFormation template for this stack.
+        :param assume_role_arn: The role that needs to be assumed to deploy the stack. Default: - No role is assumed (current credentials are used)
+        :param cloud_formation_execution_role_arn: The role that is passed to CloudFormation to execute the change set. Default: - No role is passed (currently assumed role/credentials are used)
+        :param parameters: Values for CloudFormation stack parameters that should be passed when the stack is deployed. Default: - No parameters
+        :param requires_bootstrap_stack_version: Version of bootstrap stack required to deploy this stack. Default: - No bootstrap stack required
+        :param stack_name: The name to use for the CloudFormation stack. Default: - name derived from artifact ID
+        :param stack_template_asset_object_url: If the stack template has already been included in the asset manifest, its asset URL. Default: - Not uploaded yet, upload just before deploying
+        :param termination_protection: Whether to enable termination protection for this stack. Default: false
+        """
+        self._values = {
+            'template_file': template_file,
+        }
+        if assume_role_arn is not None: self._values["assume_role_arn"] = assume_role_arn
+        if cloud_formation_execution_role_arn is not None: self._values["cloud_formation_execution_role_arn"] = cloud_formation_execution_role_arn
+        if parameters is not None: self._values["parameters"] = parameters
+        if requires_bootstrap_stack_version is not None: self._values["requires_bootstrap_stack_version"] = requires_bootstrap_stack_version
+        if stack_name is not None: self._values["stack_name"] = stack_name
+        if stack_template_asset_object_url is not None: self._values["stack_template_asset_object_url"] = stack_template_asset_object_url
+        if termination_protection is not None: self._values["termination_protection"] = termination_protection
+
+    @builtins.property
+    def template_file(self) -> str:
+        """A file relative to the assembly root which contains the CloudFormation template for this stack."""
+        return self._values.get('template_file')
+
+    @builtins.property
+    def assume_role_arn(self) -> typing.Optional[str]:
+        """The role that needs to be assumed to deploy the stack.
+
+        default
+        :default: - No role is assumed (current credentials are used)
+        """
+        return self._values.get('assume_role_arn')
+
+    @builtins.property
+    def cloud_formation_execution_role_arn(self) -> typing.Optional[str]:
+        """The role that is passed to CloudFormation to execute the change set.
+
+        default
+        :default: - No role is passed (currently assumed role/credentials are used)
+        """
+        return self._values.get('cloud_formation_execution_role_arn')
+
+    @builtins.property
+    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
+        """Values for CloudFormation stack parameters that should be passed when the stack is deployed.
+
+        default
+        :default: - No parameters
+        """
+        return self._values.get('parameters')
+
+    @builtins.property
+    def requires_bootstrap_stack_version(self) -> typing.Optional[jsii.Number]:
+        """Version of bootstrap stack required to deploy this stack.
+
+        default
+        :default: - No bootstrap stack required
+        """
+        return self._values.get('requires_bootstrap_stack_version')
+
+    @builtins.property
+    def stack_name(self) -> typing.Optional[str]:
+        """The name to use for the CloudFormation stack.
+
+        default
+        :default: - name derived from artifact ID
+        """
+        return self._values.get('stack_name')
+
+    @builtins.property
+    def stack_template_asset_object_url(self) -> typing.Optional[str]:
+        """If the stack template has already been included in the asset manifest, its asset URL.
+
+        default
+        :default: - Not uploaded yet, upload just before deploying
+        """
+        return self._values.get('stack_template_asset_object_url')
+
+    @builtins.property
+    def termination_protection(self) -> typing.Optional[bool]:
+        """Whether to enable termination protection for this stack.
+
+        default
+        :default: false
+        """
+        return self._values.get('termination_protection')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'AwsCloudFormationStackProperties(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.ContainerImageAssetMetadataEntry", jsii_struct_bases=[], name_mapping={'id': 'id', 'packaging': 'packaging', 'path': 'path', 'source_hash': 'sourceHash', 'build_args': 'buildArgs', 'file': 'file', 'image_name_parameter': 'imageNameParameter', 'image_tag': 'imageTag', 'repository_name': 'repositoryName', 'target': 'target'})
 class ContainerImageAssetMetadataEntry():
     def __init__(self, *, id: str, packaging: str, path: str, source_hash: str, build_args: typing.Optional[typing.Mapping[str, str]]=None, file: typing.Optional[str]=None, image_name_parameter: typing.Optional[str]=None, image_tag: typing.Optional[str]=None, repository_name: typing.Optional[str]=None, target: typing.Optional[str]=None) -> None:
@@ -465,6 +607,48 @@ class ContextProvider(enum.Enum):
     """SSM Parameter Provider."""
     VPC_PROVIDER = "VPC_PROVIDER"
     """VPC Provider."""
+    ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = "ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER"
+    """VPC Endpoint Service AZ Provider."""
+
+@jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.EndpointServiceAvailabilityZonesContextQuery", jsii_struct_bases=[], name_mapping={'account': 'account', 'region': 'region', 'service_name': 'serviceName'})
+class EndpointServiceAvailabilityZonesContextQuery():
+    def __init__(self, *, account: str, region: str, service_name: str) -> None:
+        """Query to endpoint service context provider.
+
+        :param account: Query account.
+        :param region: Query region.
+        :param service_name: Query service name.
+        """
+        self._values = {
+            'account': account,
+            'region': region,
+            'service_name': service_name,
+        }
+
+    @builtins.property
+    def account(self) -> str:
+        """Query account."""
+        return self._values.get('account')
+
+    @builtins.property
+    def region(self) -> str:
+        """Query region."""
+        return self._values.get('region')
+
+    @builtins.property
+    def service_name(self) -> str:
+        """Query service name."""
+        return self._values.get('service_name')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'EndpointServiceAvailabilityZonesContextQuery(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
 
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.FileAssetMetadataEntry", jsii_struct_bases=[], name_mapping={'artifact_hash_parameter': 'artifactHashParameter', 'id': 'id', 'packaging': 'packaging', 'path': 'path', 's3_bucket_parameter': 's3BucketParameter', 's3_key_parameter': 's3KeyParameter', 'source_hash': 'sourceHash'})
 class FileAssetMetadataEntry():
@@ -677,7 +861,7 @@ class MetadataEntry():
 
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.MissingContext", jsii_struct_bases=[], name_mapping={'key': 'key', 'props': 'props', 'provider': 'provider'})
 class MissingContext():
-    def __init__(self, *, key: str, props: typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery"], provider: "ContextProvider") -> None:
+    def __init__(self, *, key: str, props: typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery", "EndpointServiceAvailabilityZonesContextQuery"], provider: "ContextProvider") -> None:
         """Represents a missing piece of context.
 
         :param key: The missing context key.
@@ -696,7 +880,7 @@ class MissingContext():
         return self._values.get('key')
 
     @builtins.property
-    def props(self) -> typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery"]:
+    def props(self) -> typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery", "EndpointServiceAvailabilityZonesContextQuery"]:
         """A set of provider-specific options."""
         return self._values.get('props')
 
@@ -814,6 +998,32 @@ class Tag():
         return 'Tag(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.TreeArtifactProperties", jsii_struct_bases=[], name_mapping={'file': 'file'})
+class TreeArtifactProperties():
+    def __init__(self, *, file: str) -> None:
+        """Artifact properties for the Construct Tree Artifact.
+
+        :param file: Filename of the tree artifact.
+        """
+        self._values = {
+            'file': file,
+        }
+
+    @builtins.property
+    def file(self) -> str:
+        """Filename of the tree artifact."""
+        return self._values.get('file')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'TreeArtifactProperties(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 @jsii.data_type(jsii_type="@aws-cdk/cloud-assembly-schema.VpcContextQuery", jsii_struct_bases=[], name_mapping={'account': 'account', 'filter': 'filter', 'region': 'region', 'return_asymmetric_subnets': 'returnAsymmetricSubnets', 'subnet_group_name_tag': 'subnetGroupNameTag'})
 class VpcContextQuery():
     def __init__(self, *, account: str, filter: typing.Mapping[str, str], region: str, return_asymmetric_subnets: typing.Optional[bool]=None, subnet_group_name_tag: typing.Optional[str]=None) -> None:
@@ -892,9 +1102,12 @@ __all__ = [
     "ArtifactMetadataEntryType",
     "ArtifactType",
     "AssemblyManifest",
+    "AssetManifestProperties",
     "AvailabilityZonesContextQuery",
+    "AwsCloudFormationStackProperties",
     "ContainerImageAssetMetadataEntry",
     "ContextProvider",
+    "EndpointServiceAvailabilityZonesContextQuery",
     "FileAssetMetadataEntry",
     "HostedZoneContextQuery",
     "Manifest",
@@ -903,6 +1116,7 @@ __all__ = [
     "RuntimeInfo",
     "SSMParameterContextQuery",
     "Tag",
+    "TreeArtifactProperties",
     "VpcContextQuery",
 ]
 
